import os

from deploy import colorized_output as co
from deploy.deployment import Deployment

from invoke import task


def set_ctx(ctx, host):
    deployment = Deployment(host)
    ctx.update({'deploy': deployment})


@task(help={'host': "IP of the txt-controller"})
def copy_ssh_key(ctx, host):
    """
    copy the own ssh-key to the txt-controller
    """
    set_ctx(ctx, host)
    ctx.deploy.copy_ssh_key()


@task(help={'host': "IP of the txt-controller"})
def mount(ctx, host):
    """
    mounts the needed directories on the txt-controller
    """
    set_ctx(ctx, host)
    ctx.deploy.check_mounts()


@task(help={'host': "IP of the txt-controller"})
def install_python(ctx, host):
    """
    installs pip and dependencies on the txt-controller
    """
    set_ctx(ctx, host)
    ctx.deploy.check_pip_and_libraries()


@task(help={'host': "IP of the txt-controller"})
def run_tests(ctx, host):
    """
    Runs the tests
    """
    set_ctx(ctx, host)
    ctx.deploy.run_tests()


@task(help={'host': "IP of the txt-controller"})
def deploySSH(ctx, host):
    """
    Deploy ssh credentials
    """
    set_ctx(ctx, host)
    co.print_info("Step 1/1 >> Copying SSH-Key to TXT")
    copy_ssh_key(ctx, host)
    co.print_success('Deployment successfully finished!')


@task(help={'host': "IP of the txt-controller"})
def deploy(ctx, host):
    """
    Setup and deploy controllerlib
    """
    set_ctx(ctx, host)
    co.print_info("Step 1/3 >> Creating mounts")
    mount(ctx, host)
    co.print_info("Step 2/3 >> Installing pip and dependencies")
    install_python(ctx, host)
    co.print_success('Deployment successfully finished!')
    set_ctx(ctx, host)
    co.print_info("Step 3/3 >> Copying 'tests' folder...")
    run_tests(ctx, host)
