from deploy import colorized_output as co
from deploy.deployment import Deployment
from invoke import task


def set_ctx(ctx, host):
    deployment = Deployment(host)
    ctx.update({'deploy': deployment})

@task(help={'host': "IP of the txt-controller"})
def build_package(ctx, host):
    set_ctx(ctx, host)
    ctx.deploy.build_package()


@task(help={'host': "IP of the txt-controller"})
def upload_package(ctx, host):
    set_ctx(ctx, host)
    ctx.deploy.upload_package()

@task(help={'host': "IP of the txt-controller"})
def install_package(ctx, host):
    set_ctx(ctx, host)
    ctx.deploy.install_package()

@task(help={'host': "IP of the txt-controller"})
def upload_tests(ctx, host):
    set_ctx(ctx, host)
    ctx.deploy.upload_tests("../../tests")

@task(help={'host': "IP of the txt-controller"})
def run_tests(ctx, host):
    set_ctx(ctx, host)
    ctx.deploy.run_tests()

@task(help={'host': "IP of the txt-controller"})
def clean_up(ctx, host):
    set_ctx(ctx, host)
    ctx.deploy.clean_up()


@task(help={'host': "IP of the txt-controller"})
def deploy(ctx, host):

    """
    Setup and deploy controllerlib
    """
    set_ctx(ctx, host)
    set_ctx(ctx, host)
    co.print_info("Step 1/6 >> Clean up")
    clean_up(ctx, host)
    co.print_info("Step 2/6 >> Build Package")
    build_package(ctx, host)
    co.print_info("Step 3/6 >> Upload Package")
    upload_package(ctx, host)
    co.print_info("Step 4/6 >> Install Package")
    install_package(ctx, host)
    co.print_info("Step 5/6 >> Upload Tests")
    upload_tests(ctx, host)
    co.print_info("Step 6/6 >> Run Tests")
    run_tests(ctx, host)
