import cv2
import numpy as np

from .Detector import Detector


class ImageClassifier(Detector):

    def process_image(self, image, k=0):
        r"""Process an image, Return top K result in a list of 2-Tuple(confidence_score, _id)"""
        result = dict()
        if image is None:
            for label in self.labels:
                result[self.labels[label]] = 0
            return dict()
        input_details = self.interpreter.get_input_details()
        input_shape = input_details[0]['shape']
        height = input_shape[1]
        width = input_shape[2]
        image = cv2.resize(image, (width, height))
        input_data = np.expand_dims(image, axis=0)  # expand to 4-dim

        # Process
        self.interpreter.set_tensor(self.interpreter.get_input_details()[0]['index'], input_data)
        self.interpreter.invoke()

        # Get outputs
        output_details = self.interpreter.get_output_details()
        output_data = self.interpreter.get_tensor(output_details[0]['index'])
        output_data = np.squeeze(output_data)

        # Get top K result
        top_k = output_data.argsort()[-k:][::-1]  # Top_k index
        for _id in top_k:
            score = float(output_data[_id] / 255.0)
            result[self.labels[_id]] = score

        return result
