import cv2
import numpy as np

from ..camera.VideoStream import VideoStream
from .Detector import Detector


class ObjectDetector(Detector):

    def process_image(self, image):
        r"""Process an image, Return a list of detected class ids and positions"""
        result = dict()
        if image is None:
            for label in self.labels:
                result[self.labels[label]] = 0
            return dict()
        input_details = self.interpreter.get_input_details()
        input_shape = input_details[0]['shape']
        height = input_shape[1]
        width = input_shape[2]
        image = cv2.resize(image, (width, height))
        input_data = np.expand_dims(image, axis=0)  # expand to 4-dim

        # Process
        self.interpreter.set_tensor(self.interpreter.get_input_details()[0]['index'], input_data)
        self.interpreter.invoke()

        # Get outputs
        output_details = self.interpreter.get_output_details()
        # output_details[0] - position
        # output_details[1] - class id
        # output_details[2] - score
        # output_details[3] - count

        positions = np.squeeze(self.interpreter.get_tensor(output_details[0]['index']))
        classes = np.squeeze(self.interpreter.get_tensor(output_details[1]['index']))
        scores = np.squeeze(self.interpreter.get_tensor(output_details[2]['index']))

        for idx, score in enumerate(scores):
            positions[idx][1] = int(max(0, positions[idx][1] * VideoStream.getInstance().get_width()))
            positions[idx][3] = int(min(width, positions[idx][3] * VideoStream.getInstance().get_width()))
            positions[idx][0] = int(max(0, positions[idx][0] * VideoStream.getInstance().get_height()))
            positions[idx][2] = int(min(height, positions[idx][2] * VideoStream.getInstance().get_height()))
            result[self.labels[int(classes[idx])]] = {'position': positions[idx], 'probability': score}

        return result

