import socket
import ssl

import paho.mqtt.client as mqtt


class Client:

    def __init__(self, client_id="", clean_session=True, userdata=None, protocol=mqtt.MQTTv311, transport="tcp",
                 path="/"):
        self.callbacks = {}
        self.subscribe_qos = 0
        self.connected = False
        self.paho_client = mqtt.Client(client_id, clean_session, userdata, protocol, transport)
        if transport == 'websockets':
            self.paho_client.ws_set_options(path=path)
        self.paho_client.on_disconnect = self.__on_disconnect
        self.paho_client.on_connect = self.__on_connect
        self.paho_client.on_message = self.__on_message

    def __del__(self):
        self.disconnect()

    def connect(self, host, port, keepalive, bind_address, user, password):
        if 'beemo.eu' in host or 'fischertechnik-cloud.com' in host:
            context = ssl.create_default_context()
            s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
            context.wrap_socket(s, server_hostname="*.beemo.eu")
            self.paho_client.tls_set_context(context)
        if user:
            self.paho_client.username_pw_set(user, password)
        self.paho_client.connect(host, port, keepalive, bind_address)
        self.paho_client.loop_start()

    def disconnect(self):
        if self.paho_client:
            self.paho_client.disconnect()

    def is_connected(self):
        return self.connected

    def subscribe(self, topic, callback, qos=0):
        self.subscribe_qos = qos
        self.__add_callback(topic, callback)

    def unsubscribe(self, topic, callback):
        self.__remove_callback(topic, callback)

    def publish(self, topic, payload, qos, retain):
        return self.paho_client.publish(topic, payload, qos, retain)

    def will_set(self, topic, payload=None, qos=0, retain=False):
        self.paho_client.will_set(topic, payload, qos, retain)

    def __on_connect(self, client, userdata, flags, rc):
        if rc != 0:
            print("Unexpected connection.")
        else:
            for topic in self.callbacks:
                self.paho_client.subscribe(topic, self.subscribe_qos)
            self.connected = True

    def __on_disconnect(self, client, userdata, rc):
        if rc != 0:
            print("Unexpected disconnection.")
        else:
            self.connected = False

    def __on_message(self, client, userdata, msg):
        for topic in self.callbacks:
            if mqtt.topic_matches_sub(topic, msg.topic):
                for callback in self.callbacks[topic]:
                    callback(msg)

    def __add_callback(self, topic, callback):
        if not self.__has_callback(topic, callback):
            if topic not in self.callbacks:
                self.callbacks[topic] = []
            self.callbacks[topic].append(callback)

    def __remove_callback(self, topic, callback):
        if self.__has_callback(topic, callback):
            self.callbacks[topic].remove(callback)
            if len(self.callbacks[topic]) == 0:
                del self.callbacks[topic]

    def __has_callback(self, topic, callback):
        return topic in self.callbacks and callback in self.callbacks[topic]
