from fischertechnik.factories import controller_factory, input_factory, i2c_factory
import os
from time import sleep

controller = controller_factory.create_graphical_controller()
environment_sensor = i2c_factory.create_environment_sensor(controller, 0)

# test needs_calibration()
needs_calibration = environment_sensor.needs_calibration()

if needs_calibration:
    print('Sensor needs calibration.')
else:
    print('Sensor is calibrated')

assert needs_calibration == True, 'Expected EnvironmentSensor.needs_calibration() to be True after initialization, but was {}'.format(needs_calibration)

# test get_accuracy()
accuracy = environment_sensor.get_accuracy()
print('Accuracy: {}'.format(accuracy))
assert accuracy == 0, 'Expected EnvironmentSensor.get_accuracy() to be 0 after initialization, but was {}'.format(accuracy)

i = 0
while i < 500:
    # test get_temperature()
    print('Temperature:', environment_sensor.get_temperature(), '°C')
    # test get_humidity()
    print('relative Humidity:', environment_sensor.get_humidity(), '%')
    # test get_pressure()
    print('Air pressure:', environment_sensor.get_pressure(), 'hPa')

    # test get_indoor_air_quality_as_number()
    air_quality = environment_sensor.get_indoor_air_quality_as_number()
    assert air_quality >= 0 and air_quality <= 500, 'Air quality should be within range(0, 500)'

    # test needs_calibration()
    needs_calibration = environment_sensor.needs_calibration()

    if needs_calibration:
        print('Sensor needs calibration.')
    else:
        print('Sensor is calibrated')

    assert needs_calibration == False, 'Expected sensor to be automatically calibrated after calling get_indoor_air_quality() for the first time, but it wasn\'t.'

    # test get_accuracy()
    accuracy = environment_sensor.get_accuracy()
    print('Accuracy: {}'.format(accuracy))
    assert accuracy == 3, 'Expected accuracy to be 3 (calibrated) after having called get_indoor_air_quality_*'

    # test get_indoor_air_quality_as_text()
    air_quality_text = environment_sensor.get_indoor_air_quality_as_text()
    assert air_quality_text in ('Good', 'Moderate', 'Not so good', 'Bad', 'Worse than Bad', 'Very bad')
    assert air_quality_text != 'Unknown'

    print('The air quality is', air_quality,  'which is', air_quality_text)

    sleep(1)
    os.system('clear')
    i += 1
