import os

from deploy import colorized_output as co
from deploy.mounts import Mounts
from deploy.python_environment import PythonEnvironment
from deploy.repository import Repository

from fabric import Connection

USER = 'ftc'
ROOT = 'root'

class Deployment:
    def __init__(self, host):
        self.host = host
        self.connection = Connection(host = host, user = USER)

    def check_mounts(self):
        mnts = Mounts(self.connection)
        mnts.check_mounts()

    def check_pip_and_libraries(self):
        pyenv = PythonEnvironment(self.connection)
        pyenv.check_pip()
        pyenv.check_pip_libraries()
        pyenv.add_ftc_path()

    def run_tests(self):
        repo = Repository(self.connection)
        repo.uploadFolder('../../tests')
        co.print_info("Starting tests...")
        self.connection.run("python3 /home/ftc/tests/txt/main.py")

    def build_package(self):
        os.system('cd ../../gen && ./build.sh')
        os.system('mv ../../gen/dist/ft-controllerlib-*.tar.gz ../../gen/dist/ft-controllerlib.tar.gz')

    def upload_package(self):
        repo = Repository(self.connection)
        repo.uploadFolder('../../gen/dist')

    def install_package(self):
        self.connection.run("pip3 install -I /home/ftc/gen/dist/ft-controllerlib.tar.gz")

    def clean_up(self):
        self.connection.run("rm -rf /tests")
        os.system("cd ../../gen && rm -rf dist build ft_git ft-controllerlib.egg-info")


