from deploy import colorized_output as co

class Mounts:
    MOUNTED_SUDO = '/home/ftc/mounts/usr/bin/sudo'

    def __init__(self, connection):
        self.connection = connection
        self.mounts = self.connection.run('cat /etc/mtab').stdout.strip().split()

    def create_mounts(self):
        co.print_info('Copying files to local mount folders')
        self.copy_folder_to_mounts('/usr/lib/python3.7/.', '~/mounts/python3.7')
        self.copy_folder_to_mounts('/usr/bin', '~/mounts/usr')
        self.chown_mounted_sudo()

    def copy_folder_to_mounts(self, src, dst):
        self.connection.run("mkdir -p {0}".format(dst))
        self.connection.run("cp -r {0} {1}".format(src, dst))

    def chown_mounted_sudo(self):
        self.connection.sudo("chown root:root {0}".format(Mounts.MOUNTED_SUDO))
        self.connection.sudo("chmod 4755 {0}".format(Mounts.MOUNTED_SUDO))

    def check_mounts(self):
        if not self.connection.run('ls mounts', warn=True):
            self.create_mounts()
        self.check_mount('/usr/lib/python3.7', '/home/ftc/mounts/python3.7')
        self.check_mount('/usr/bin', '/home/ftc/mounts/usr/bin')

    def check_mount(self, mnt, mnt_dir):
        co.print_info("Checking mount {0}".format(mnt))
        if mnt in self.mounts:
            co.print_success("--> Already mounted")
        else:
            co.print_warning("--> Not mounted. Please authorize sudo on txt to mount it")
            self.connection.sudo("mount {0} {1}".format(mnt_dir, mnt))
            co.print_success("--> Sucessfully mounted")