import os

from deploy import colorized_output as co
from deploy.deployment import Deployment

from invoke import task


def set_ctx(ctx, host):
    deployment = Deployment(host)
    ctx.update({'deploy': deployment})

@task(help={'host': "IP of the txt-controller"})
def mount(ctx, host):
    """
    mounts the needed directories on the txt-controller
    """
    set_ctx(ctx, host)
    ctx.deploy.check_mounts()

@task(help={'host': "IP of the txt-controller"})
def install_python(ctx, host):
    """
    installs pip and dependencies on the txt-controller
    """
    set_ctx(ctx, host)
    ctx.deploy.check_pip_and_libraries()

@task(help={'host': "IP of the txt-controller"})
def run_tests(ctx, host):
    """
    Runs the tests
    """
    set_ctx(ctx, host)
    ctx.deploy.run_tests()

@task(help={'host': "IP of the txt-controller"})
def clean_up(ctx, host):
    set_ctx(ctx, host)
    ctx.deploy.clean_up()

@task(help={'host': "IP of the txt-controller"})
def build_package(ctx, host):
    set_ctx(ctx, host)
    ctx.deploy.build_package()

@task(help={'host': "IP of the txt-controller"})
def upload_package(ctx, host):
    set_ctx(ctx, host)
    ctx.deploy.upload_package()

@task(help={'host': "IP of the txt-controller"})
def install_package(ctx, host):
    set_ctx(ctx, host)
    ctx.deploy.install_package()

@task(help={'host': "IP of the txt-controller"})
def deploy(ctx, host):
    """
    Setup and deploy controllerlib
    """
    set_ctx(ctx, host)
    co.print_info("Step 1/7 >> Creating mounts")
    mount(ctx, host)
    co.print_info("Step 2/7 >> Installing pip and dependencies")
    install_python(ctx, host)
    co.print_info("Step 3/7 >> Clean up")
    clean_up(ctx, host)
    co.print_info("Step 4/7 >> Build Package")
    build_package(ctx, host)
    co.print_info("Step 5/7 >> Upload Package")
    upload_package(ctx, host)
    co.print_info("Step 6/7 >> Install Package")
    install_package(ctx, host)
    co.print_info("Step 7/7 >> Run Tests")
    run_tests(ctx, host)
