import fischertechnik.factories as txtFactory
import time


class EncodermotorTest:
    description = "Rotate an encoder motor at 50% and expect a constant rotational speed."
    brief = "Checks rotational speed of an encoder motor."

    def __init__(self, txt):
        txtFactory.init_motor_factory()
        txtFactory.init_counter_factory()
        self.encodermotor = txtFactory.motor_factory.create_encodermotor(txt, 1)
        self.counter = txtFactory.counter_factory.create_encodermotor_counter(txt, 1)
        self.counter.set_motor(self.encodermotor)

    def does_pass(self):
        self.encodermotor.set_speed(255)
        time.sleep(2)
        start_value = self.counter.get_count()
        step_count = 0
        last_steps = 0
        millis = time.time() * 1000
        last_millis = millis
        for i in range(10):
            # Accurately sleep for 1s
            while (millis + 1000) > last_millis:
                last_millis = time.time() * 1000
            tmp = self.counter.get_count()
            steps = tmp - start_value - step_count
            if last_steps is not 0:
                if abs(steps - last_steps) > 20:
                    return False
            step_count += steps
            last_steps = steps
            millis = time.time() * 1000
        self.encodermotor.stop()
        end_value = self.counter.get_count()
        if end_value - start_value < 10:
            return False
        else:
            return True
