import time
import unittest

import fischertechnik.factories as txt_factory
from ControllerInstance import ControllerInstance
from fischertechnik.controller.Motor import Motor


class EncodermotorSync2Test(unittest.TestCase):
    SPEED = 512
    DISTANCE = 1000

    def setUp(self):
        self.controller = ControllerInstance.get_instance().get_controller()
        self.encodermotor = txt_factory.motor_factory.create_encodermotor(self.controller, 1)
        self.encodermotor2 = txt_factory.motor_factory.create_encodermotor(self.controller, 2)
        self.counter = txt_factory.counter_factory.create_encodermotor_counter(self.controller, 1)
        self.counter.set_motor(self.encodermotor)
        self.counter2 = txt_factory.counter_factory.create_encodermotor_counter(self.controller, 2)
        self.counter2.set_motor(self.encodermotor2)

    def test_motor_sync_distance(self):
        self.encodermotor.set_speed(self.SPEED, Motor.CW)
        self.encodermotor2.set_speed(self.SPEED, Motor.CCW)
        self.encodermotor.set_distance(self.DISTANCE, self.encodermotor2)
        self.assertTrue(self.encodermotor.is_running())
        self.assertTrue(self.encodermotor2.is_running())
        self.assertTrue(self.encodermotor.get_speed() == self.SPEED * Motor.CW)
        self.assertTrue(self.encodermotor2.get_speed() == self.SPEED * Motor.CCW)
        time.sleep(2)
        self.assertTrue(self.counter.get_count() > 0)
        self.assertTrue(self.counter2.get_count() > 0)
        self.encodermotor.stop_sync(self.encodermotor2)
        self.assertFalse(self.encodermotor.is_running())
        self.assertFalse(self.encodermotor2.is_running())

    def test_motor_sync(self):
        self.encodermotor.set_speed(self.SPEED, Motor.CW)
        self.encodermotor2.set_speed(self.SPEED, Motor.CCW)
        self.encodermotor.start_sync(self.encodermotor2)
        self.assertTrue(self.encodermotor.is_running())
        self.assertTrue(self.encodermotor2.is_running())
        self.assertTrue(self.encodermotor.get_speed() == self.SPEED * Motor.CW)
        self.assertTrue(self.encodermotor2.get_speed() == self.SPEED * Motor.CCW)
        time.sleep(2)
        self.assertTrue(self.counter.get_count() > 0)
        self.assertTrue(self.counter2.get_count() > 0)
        self.encodermotor.stop_sync(self.encodermotor2)
        self.assertFalse(self.encodermotor.is_running())
        self.assertFalse(self.encodermotor2.is_running())


if __name__ == '__main__':
    unittest.main()