import time
import unittest

import fischertechnik.factories as txt_factory
from ControllerInstance import ControllerInstance
from fischertechnik.controller.Motor import Motor


class EncodermotorTest(unittest.TestCase):
    SPEED = 468
    MAX_SPEED = 512

    def setUp(self):
        self.controller = ControllerInstance.get_instance().get_controller()
        self.encodermotor = txt_factory.motor_factory.create_encodermotor(self.controller, 1)

    def test_set_speed_cw_and_stop(self):
        self.encodermotor.set_speed(self.SPEED, Motor.CW)
        self.encodermotor.start()
        time.sleep(1)
        self.assertTrue(self.encodermotor.get_speed() == self.SPEED * Motor.CW)
        self.assertTrue(self.encodermotor.is_running())
        self.encodermotor.stop()
        self.assertTrue(self.encodermotor.get_speed() == 0)
        self.assertFalse(self.encodermotor.is_running())

    def test_set_speed_ccw_and_stop(self):
        self.encodermotor.set_speed(self.SPEED, Motor.CCW)
        self.encodermotor.start()
        time.sleep(1)
        self.assertTrue(self.encodermotor.get_speed() == self.SPEED * Motor.CCW)
        self.assertTrue(self.encodermotor.is_running())
        self.encodermotor.stop()
        self.assertTrue(self.encodermotor.get_speed() == 0)
        self.assertFalse(self.encodermotor.is_running())

    def test_speed_limits(self):
        self.assertRaises(ValueError, self.encodermotor.set_speed, self.MAX_SPEED + 1, Motor.CW)
        self.assertRaises(ValueError, self.encodermotor.set_speed, self.MAX_SPEED + 1, Motor.CCW)

if __name__ == '__main__':
    unittest.main()