import time
import unittest

import fischertechnik.factories as txt_factory
from ControllerInstance import ControllerInstance


class LEDTest(unittest.TestCase):

    MIN_VALUE = 0
    MAX_VALUE = 512

    def setUp(self):
        self.controller = ControllerInstance.get_instance().get_controller()
        self.led = txt_factory.output_factory.create_led(self.controller, 7)
        self.led2 = txt_factory.output_factory.create_led(self.controller, 8)
        time.sleep(1)

    def test_setting_brightness_led1(self):
        self.assertFalse(self.led.is_on())
        self.assertTrue(self.led.is_off())
        self.assertTrue(self.led.get_brightness() == 0)

        self.led.set_brightness(512)

        self.assertTrue(self.led.is_on())
        self.assertFalse(self.led.is_off())
        self.assertTrue(self.led.get_brightness() == 512)

        self.led.set_brightness(0)

        self.assertFalse(self.led.is_on())
        self.assertTrue(self.led.is_off())
        self.assertTrue(self.led.get_brightness() == 0)

    def test_setting_brightness_led2(self):
        self.assertFalse(self.led2.is_on())
        self.assertTrue(self.led2.is_off())
        self.assertTrue(self.led2.get_brightness() == 0)

        self.led2.set_brightness(150)

        self.assertTrue(self.led2.is_on())
        self.assertFalse(self.led2.is_off())
        self.assertTrue(self.led2.get_brightness() == 150)

        self.led2.set_brightness(0)

        self.assertFalse(self.led2.is_on())
        self.assertTrue(self.led2.is_off())
        self.assertTrue(self.led2.get_brightness() == 0)

    def test_value_limits(self):
        self.assertRaises(ValueError, self.led.set_brightness, self.MIN_VALUE - 1)
        self.assertRaises(ValueError, self.led2.set_brightness, self.MAX_VALUE + 1)


if __name__ == '__main__':
    unittest.main()
