import time
import unittest

import fischertechnik.factories as txt_factory
from ControllerInstance import ControllerInstance
from fischertechnik.controller.Motor import Motor


class MotorTest(unittest.TestCase):

    SPEED = 255

    def setUp(self):
        self.controller = ControllerInstance.get_instance().get_controller()
        self.motor = txt_factory.motor_factory.create_motor(self.controller, 3)

    def test_set_speed_cw_and_stop(self):
        self.motor.set_speed(self.SPEED, Motor.CW)
        self.motor.start()
        time.sleep(1)
        self.assertTrue(self.motor.get_speed() == self.SPEED * Motor.CW)
        self.assertTrue(self.motor.is_running())
        self.motor.stop()
        self.assertTrue(self.motor.get_speed() == 0)
        self.assertFalse(self.motor.is_running())

    def test_set_speed_ccw_and_stop(self):
        self.motor.set_speed(self.SPEED, Motor.CCW)
        self.motor.start()
        time.sleep(1)
        self.assertTrue(self.motor.get_speed() == self.SPEED * Motor.CCW)
        self.assertTrue(self.motor.is_running())
        self.motor.stop()
        self.assertTrue(self.motor.get_speed() == 0)
        self.assertFalse(self.motor.is_running())

    def test_motor_coast(self):
        self.skipTest('Skip until bug is fixed that after coast motor still returns isrunning == True')
        self.motor.set_speed(self.SPEED, Motor.CCW)
        self.motor.start()
        time.sleep(1)
        self.motor.coast()
        time.sleep(3)
        self.assertFalse(self.motor.is_running())


if __name__ == '__main__':
    unittest.main()
