import random
import time
import unittest
import fischertechnik.factories as txt_factory
from ControllerInstance import ControllerInstance

class ServomotorTest(unittest.TestCase):

    MIN_POSITION = 0
    MAX_POSITION = 512

    def setUp(self):
        self.controller = ControllerInstance.get_instance().get_controller()
        self.servo1 = txt_factory.servomotor_factory.create_servomotor(self.controller, 1)
        self.servo2 = txt_factory.servomotor_factory.create_servomotor(self.controller, 2)
        self.servo3 = txt_factory.servomotor_factory.create_servomotor(self.controller, 3)
        time.sleep(1)

    def tearDown(self):
        self.servo1.set_position(256)
        self.servo2.set_position(256)
        self.servo3.set_position(256)


    def test_servo1(self):
        position = random.randint(50, 500)
        self.servo1.set_position(position)
        self.assertTrue(self.servo1.get_position() == position)

    def test_servo2(self):
        position = random.randint(50, 500)
        self.servo2.set_position(position)
        self.assertTrue(self.servo2.get_position() == position)

    def test_servo3(self):
        position = random.randint(50, 500)
        self.servo3.set_position(position)
        self.assertTrue(self.servo3.get_position() == position)

    def test_position_limits(self):
        self.assertRaises(ValueError, self.servo1.set_position, self.MIN_POSITION - 1)
        self.assertRaises(ValueError, self.servo2.set_position, self.MAX_POSITION + 1)

if __name__ == '__main__':
    unittest.main()
